@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 1998-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -17,10 +17,10 @@
 # Postorius.  If not, see <http://www.gnu.org/licenses/>.
 
 
-from django.urls import include, re_path
+from django.conf import settings
 from django.contrib import admin
 from django.http import Http404
-from django.urls import reverse_lazy
+from django.urls import include, path, re_path, reverse_lazy
 from django.views.defaults import server_error
 from django.views.generic import RedirectView
 
@@ -44,3 +44,10 @@ urlpatterns = [
     # Django admin
     re_path(r'^admin/', admin.site.urls),
 ]
+
+
+if settings.DEBUG:
+    import debug_toolbar
+    urlpatterns = [
+        path('__debug__/', include(debug_toolbar.urls)),
+    ] + urlpatterns
