@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2017-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2017-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -81,7 +81,7 @@ class ListNew(forms.Form):
             (False, _("Hide this list in list index"))))
     list_style = forms.ChoiceField()
     description = forms.CharField(
-        label=_('Description'),
+        label=_('Short Description'),
         required=False)
 
     def __init__(self, domain_choices, style_choices, *args, **kwargs):
@@ -413,7 +413,7 @@ class MessageAcceptanceForm(ListSettingsForm):
         help_text=_(
             'Administrivia tests will check postings to see whether it\'s '
             'really meant as an administrative request (like subscribe, '
-            'unsubscribe, etc), and will add it to the the administrative '
+            'unsubscribe, etc), and will add it to the administrative '
             'requests queue, notifying the administrator of the new request, '
             'in the process.'))
     default_member_action = forms.ChoiceField(
@@ -957,7 +957,7 @@ class ListIdentityForm(ListSettingsForm):
         help_text=_('Choose whether to include this list '
                     'on the list of all lists'))
     description = forms.CharField(
-        label=_('Description'),
+        label=_('Short Description'),
         required=False,
         help_text=_(
             'This description is used when the mailing list is listed with '
@@ -966,7 +966,7 @@ class ListIdentityForm(ListSettingsForm):
             'list is.'),
     )
     info = forms.CharField(
-        label=_('Information'),
+        label=_('Long Description'),
         help_text=_('A longer description of this mailing list.'),
         required=False,
         widget=forms.Textarea())
