@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2017-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2017-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -32,4 +32,4 @@ class MemberForm(forms.Form):
         label=_('Display Name'),
         required=False,
         error_messages={
-            'invalid': _('Please enter an display name.')})
+            'invalid': _('Please enter a display name.')})
