@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 1998-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -28,6 +28,7 @@ from django.db.models.signals import post_delete, post_save
 from django.dispatch import receiver
 from django.http import Http404
 from django.urls import reverse
+from django.utils.text import format_lazy
 from django.utils.translation import gettext_lazy as _
 
 from mailmanclient import MailmanConnectionError
@@ -63,6 +64,19 @@ class SubscriptionMode(Enum):
     as_user = 'as_user'
 
 
+class MemberRole(Enum):
+    """List of roles a Member resource can have.
+
+    The primary purpose of this enum right now is only to add the
+    role values to translations. At some point, we want to use MemberRole.owner
+    in all the places we are using the literal role as string.
+    """
+    owner = _('owner')
+    member = _('member')
+    nonmember = _('nonmember')
+    moderator = _('moderator')
+
+
 class MailmanApiError(Exception):
     """Raised if the API is not available.
     """
@@ -231,7 +245,7 @@ class EmailTemplate(models.Model):
     # template file's name (key) prepended in square brackets to the
     # template's purpose (value).
     _templates_list_choices = [
-        (t[0], "[{key}] - {value}".format(key=t[0], value=t[1]))
+        (t[0], format_lazy("[{key}] - {value}", key=t[0], value=t[1]))
         for t in TEMPLATES_LIST
     ]
 
