@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 1998-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -34,6 +34,7 @@ from django.shortcuts import redirect, render
 from django.urls import reverse
 from django.utils.decorators import method_decorator
 from django.utils.translation import gettext as _
+from django.utils.translation import gettext_lazy
 from django.views.decorators.http import require_http_methods
 
 from allauth.account.models import EmailAddress
@@ -90,7 +91,7 @@ class ListMembersViews(ListOwnerMixin, MailingListView):
         """Prepare regex based query to search partial email addresses.
 
         Core's `members/find` API allows searching for memberships based on
-        regex. This methods prepares a valid regex to pass on the the REST API.
+        regex. This methods prepares a valid regex to pass on the REST API.
         """
         if request.GET.get('q'):
             query = request.GET['q']
@@ -112,6 +113,7 @@ class ListMembersViews(ListOwnerMixin, MailingListView):
             return redirect('list_members', list_id, 'member')
         context = dict()
         context['list'] = self.mailing_list
+        # Warning: role not translatable
         context['role'] = role
         context['member_form'] = member_form
         context['page_title'] = _('List {}s'.format(role.capitalize()))
@@ -1104,15 +1106,15 @@ def handle_subscription_request(request, list_id, request_id):
 
 
 SETTINGS_SECTION_NAMES = (
-    ('list_identity', _('List Identity')),
-    ('automatic_responses', _('Automatic Responses')),
-    ('alter_messages', _('Alter Messages')),
-    ('dmarc_mitigations', _('DMARC Mitigations')),
-    ('digest', _('Digest')),
-    ('message_acceptance', _('Message Acceptance')),
-    ('archiving', _('Archiving')),
-    ('subscription_policy', _('Member Policy')),
-    ('bounce_processing', _('Bounce Processing')),
+    ('list_identity', gettext_lazy('List Identity')),
+    ('automatic_responses', gettext_lazy('Automatic Responses')),
+    ('alter_messages', gettext_lazy('Alter Messages')),
+    ('dmarc_mitigations', gettext_lazy('DMARC Mitigations')),
+    ('digest', gettext_lazy('Digest')),
+    ('message_acceptance', gettext_lazy('Message Acceptance')),
+    ('archiving', gettext_lazy('Archiving')),
+    ('subscription_policy', gettext_lazy('Member Policy')),
+    ('bounce_processing', gettext_lazy('Bounce Processing')),
 )
 
 SETTINGS_FORMS = {
@@ -1151,7 +1153,7 @@ def list_settings(request, list_id=None, visible_section=None,
     m_list = List.objects.get_or_404(fqdn_listname=list_id)
     list_settings = m_list.settings
     initial_data = dict((key, value) for key, value in list_settings.items())
-    # List settings are grouped an processed in different forms.
+    # List settings are grouped and processed in different forms.
     if request.method == 'POST':
         form = form_class(request.POST, mlist=m_list, initial=initial_data)
         if form.is_valid():
