@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 1998-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -25,7 +25,7 @@ from django.contrib.auth.decorators import login_required
 from django.contrib.auth.forms import AdminPasswordChangeForm
 from django.forms import formset_factory
 from django.http import Http404
-from django.shortcuts import render
+from django.shortcuts import redirect, render
 from django.urls import reverse, reverse_lazy
 from django.utils.decorators import method_decorator
 from django.utils.translation import gettext as _
@@ -131,7 +131,7 @@ class UserMailmanSettingsView(UserPreferencesView):
             if key != "self_link":
                 combinedpreferences[key] = self.mm_user.preferences[key]
 
-        return(combinedpreferences)
+        return (combinedpreferences)
 
 
 class UserAddressPreferencesView(UserPreferencesView):
@@ -435,6 +435,9 @@ def manage_user(request, user_id):
                 change_password.fields[
                     'password1'].widget.attrs['autofocus'] = False
 
+        return redirect(reverse('manage_user', args=(user_id,)))
+
+    # In case of GET request, return the formsets with initial data.
     return render(request,
                   'postorius/user/manage.html',
                   {'auser': user,
